@@ -17,6 +17,7 @@ DESCRIPTION = """
 import random
 import argparse
 import irbench.dataset as irds
+import numpy as np
 
 
 def getargs():
@@ -27,8 +28,9 @@ def getargs():
                                      formatter_class=
                                      argparse.RawTextHelpFormatter)
     subparsers = parser.add_subparsers(dest='dataset', help='dataset help')
-    for (name, cls) in irds.DATASETS.iteritems():
+    for (name, cls) in irds.DS_BUILDERS.iteritems():
         ds_parser = subparsers.add_parser(name, help=cls.__doc__)
+        print name, cls
         cls.set_parser(ds_parser)
     parser.add_argument('seed', type=int, nargs='?', default=0,
                         help="seed for random number generator")
@@ -42,9 +44,11 @@ def main(args):
 
     # to ensure that the generated list is consistent every time
     random.seed(args.seed)
+    np.random.seed(args.seed)
 
-    dataset = irds.DATASETS[args.dataset](args)
-    dataset.generate(args.trg_dir)
+    builder = irds.DS_BUILDERS[args.dataset](args)
+    builder.generate(args.trg_dir)
+    builder.save(args.trg_dir + ".pkl")
 
 if __name__ == '__main__':
     main(getargs())
