@@ -84,7 +84,7 @@ class Indexer(object):
         # diagnaol metric
         elif metric.ndim == 1:
             self.distfunc = DotProduct_DML_Diagonal
-            self.dim_mask = (metric != 0)
+            self.dim_mask = np.arange(metric.shape[0])[metric != 0]
             self.metric = metric[self.dim_mask]
         # dense metric
         elif metric.ndim == 2:
@@ -570,8 +570,12 @@ class Inverted(Linear):
         logging.info("Adjusting index - ^^^^^")
         tic()
         for i in xrange(len(self.idxs)):
-            self.idxs[i] = (np.frombuffer(self.idxs[i][0], self.IDX_NPY_TYPE),
-                            np.frombuffer(self.idxs[i][1], self.VAL_NPY_TYPE))
+            if len(self.idxs[i][0]) == 0:
+                self.idxs[i] = (np.ndarray(0, self.IDX_NPY_TYPE),
+                                np.ndarray(0, self.VAL_NPY_TYPE))
+            else:
+                self.idxs[i] = (np.frombuffer(self.idxs[i][0], self.IDX_NPY_TYPE),
+                                np.frombuffer(self.idxs[i][1], self.VAL_NPY_TYPE))
         logging.info("Adjusting index - $$$$$ (Time costs: %.4fs)!" % toc())
 
     def query_batch(self, query, topk):
